summaryrefslogtreecommitdiffstats
path: root/kolf/objects/test/test.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kolf/objects/test/test.cpp')
-rw-r--r--kolf/objects/test/test.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kolf/objects/test/test.cpp b/kolf/objects/test/test.cpp
index eabc2e7e..331975fc 100644
--- a/kolf/objects/test/test.cpp
+++ b/kolf/objects/test/test.cpp
@@ -52,14 +52,14 @@ void Test::advance(int phase)
}
}
-void Test::save(KConfig *cfg)
+void Test::save(TDEConfig *cfg)
{
// save our option from the course
// (courses are represented as KConfig files)
cfg->writeEntry("switchEvery", switchEvery());
}
-void Test::load(KConfig *cfg)
+void Test::load(TDEConfig *cfg)
{
// load our option
setSwitchEvery(cfg->readNumEntry("switchEvery", 50));
@@ -52,14 +52,14 @@ void Test::advance(int phase)
{
// save our option from the course
- // (courses are represented as KConfig files)
+ // (courses are represented as TDEConfig files)
cfg->writeEntry("switchEvery", switchEvery());
}